function createStore(reducer, state) {
    if ( state === void 0 ) state = {};

    var subscribers = [];
    return {
        getState: function getState() {
            return state;
        },
        dispatch: function dispatch(action) {
            state = reducer(state, action);
            subscribers.forEach(function (handler) { return handler(); });
        },
        subscribe: function subscribe(handler) {
            subscribers.push(handler);
            return function unsubscribe() {
                var index = subscribers.indexOf(handler);
                if (index > 0) {
                    subscribers.splice(index, 1);
                }
            };
        }
    };
}

module.exports = createStore;
